@@ -159,6 +159,18 @@ def run():
         action="store_true",
         help="Turn on debugging logs",
     )
+    parser.add_argument(
+        "--local",
+        action="store_true",
+        default=False,
+        help="Perform rsync transfers locally rather than remotely",
+    )
+    parser.add_argument(
+        "--force_mdoc_metadata",
+        action="store_true",
+        default=False,
+        help="Force metadata to be read from mdoc files",
+    )
 
     args = parser.parse_args()
 
@@ -265,6 +277,7 @@ def run():
         default_destination=args.destination
         or f"{machine_data.get('rsync_module') or 'data'}/{datetime.now().year}",
         demo=args.demo,
+        processing_only_mode=server_routing_prefix_found,
     )
 
     ws.environment = instance_environment
@@ -273,7 +286,7 @@ def run():
         instance_environment.source,
         basepath_remote=Path(args.destination or f"data/{datetime.now().year}"),
         server_url=murfey_url,
-        local=instance_environment.demo,
+        local=args.local or instance_environment.demo,
         do_transfer=not args.no_transfer,
     )
     source_watcher.subscribe(rsync_process.enqueue)
@@ -281,6 +294,7 @@ def run():
     analyser = Analyser(
         instance_environment.source,
         environment=instance_environment if args.real_dc else None,
+        force_mdoc_metadata=args.force_mdoc_metadata,
     )
     # source_watcher.subscribe(analyser.enqueue)
     rsync_process.subscribe(analyser.enqueue)
