@@ -78,6 +78,8 @@ class TomographyContext(Context):
         self._processing_job_stash: dict = {}
         self._preprocessing_triggers: dict = {}
         self._lock: RLock = RLock()
+        self._extract_tilt_series: Callable[[Path], str] | None = None
+        self._extract_tilt_tag: Callable[[Path], str] | None = None
 
     def _flush_data_collections(self):
         logger.info("Flushing data collection API calls")
@@ -87,16 +89,16 @@ class TomographyContext(Context):
         self._data_collection_stash = []
 
     def _flush_processing_job(self, tag: str):
-        logger.info(
-            f"Flushing processing job {tag}, {self._processing_job_stash.get(tag)}"
-        )
+        # logger.info(
+        #     f"Flushing processing job {tag}, {self._processing_job_stash.get(tag)}"
+        # )
         if proc_data := self._processing_job_stash.get(tag):
             for pd in proc_data:
                 requests.post(pd[0], json=pd[1])
             self._processing_job_stash.pop(tag)
 
     def _flush_preprocess(self, tag: str, app_id: int):
-        logger.info(f"Flushing preprocessing requests {tag}")
+        # logger.info(f"Flushing preprocessing requests {tag}")
         if tag_tr := self._preprocessing_triggers.get(tag):
             for tr in tag_tr:
                 process_file = self._complete_process_file(tr[1], tr[2], app_id)
@@ -115,31 +117,13 @@ class TomographyContext(Context):
         mvid: int,
         tilt_angles: List,
     ):
-        if self._acquisition_software == "serialem":
-            delimiters = ("_", "-")
-            for d in delimiters:
-                if movie_path.name.count(d) > 1:
-                    delimiter = d
-                    break
-            else:
-                delimiter = delimiters[0]
-
-            def _extract_tilt_series(p: Path) -> str:
-                split = p.name.split(delimiter)
-                for s in split:
-                    if s.isdigit():
-                        return s
-                raise ValueError(
-                    f"No digits found in {p.name} after splitting on {delimiter}"
-                )
-
-            tilt_series = _extract_tilt_series(movie_path)
-            # tilt_angle = ".".join(movie_path.name.split(delimiter)[-1].split(".")[:-1])
-        elif self._acquisition_software == "tomo":
-            tilt_series = movie_path.name.split("_")[1]
-            # tilt_angle = movie_path.name.split("[")[1].split("]")[0]
+        if self._extract_tilt_series and self._extract_tilt_tag:
+            tilt_series = self._extract_tilt_tag(
+                movie_path
+            ) + self._extract_tilt_series(movie_path)
         else:
             return
+
         if self._motion_corrected_tilt_series.get(
             tilt_series
         ) and motion_corrected_path not in self._motion_corrected_tilt_series.get(
@@ -151,9 +135,6 @@ class TomographyContext(Context):
         else:
             self._motion_corrected_tilt_series[tilt_series] = [motion_corrected_path]
         if tilt_series in self._completed_tilt_series:
-            logger.info(
-                f"LENGTHS {len(self._motion_corrected_tilt_series[tilt_series])}, {len(self._tilt_series[tilt_series])}"
-            )
             if (
                 len(self._motion_corrected_tilt_series[tilt_series])
                 == len(self._tilt_series[tilt_series])
@@ -213,20 +194,27 @@ class TomographyContext(Context):
         file_path: Path,
         extract_tilt_series: Callable[[Path], str],
         extract_tilt_angle: Callable[[Path], str],
+        extract_tilt_tag: Callable[[Path], str],
         environment: MurfeyInstanceEnvironment | None = None,
     ) -> List[str]:
+        if not self._extract_tilt_series:
+            self._extract_tilt_series = extract_tilt_series
+        if not self._extract_tilt_tag:
+            self._extract_tilt_tag = extract_tilt_tag
         # time.sleep(5)
         try:
-            tilt_series = extract_tilt_series(file_path)
+            tilt_series_num = extract_tilt_series(file_path)
             tilt_angle = extract_tilt_angle(file_path)
+            tilt_tag = extract_tilt_tag(file_path)
             try:
-                float(tilt_series)
+                float(tilt_series_num)
                 float(tilt_angle)
             except ValueError:
                 return []
+            tilt_series = tilt_tag + tilt_series_num
 
         except Exception:
-            logger.debug(
+            logger.info(
                 f"Tilt series and angle could not be determined for {file_path}"
             )
             return []
@@ -280,7 +268,7 @@ class TomographyContext(Context):
                     url = f"{str(environment.url.geturl())}/visits/{environment.visit}/start_data_collection"
                     data = {
                         "experiment_type": "tomography",
-                        "tilt": tilt_series,
+                        "tilt": tilt_series_num,
                         "file_extension": file_path.suffix,
                         "acquisition_software": self._acquisition_software,
                         "image_directory": str(file_path.parent),
@@ -392,7 +380,9 @@ class TomographyContext(Context):
                     ]
 
         if self._last_transferred_file:
-            last_tilt_series = extract_tilt_series(self._last_transferred_file)
+            last_tilt_series = extract_tilt_tag(
+                self._last_transferred_file
+            ) + extract_tilt_series(self._last_transferred_file)
             last_tilt_angle = extract_tilt_angle(self._last_transferred_file)
             self._last_transferred_file = file_path
             if last_tilt_series != tilt_series and last_tilt_angle != tilt_angle:
@@ -460,10 +450,10 @@ class TomographyContext(Context):
                                         ),
                                         file_tilt_list,
                                     )
-
-                logger.info(
-                    f"The following tilt series are considered complete: {newly_completed_series}"
-                )
+                if newly_completed_series:
+                    logger.info(
+                        f"The following tilt series are considered complete: {newly_completed_series}"
+                    )
                 return newly_completed_series
         self._last_transferred_file = file_path
         return []
@@ -476,17 +466,41 @@ class TomographyContext(Context):
                 file_path,
                 lambda x: x.name.split("_")[1],
                 lambda x: x.name.split("[")[1].split("]")[0],
+                lambda x: x.name.split("_")[0],
                 environment=environment,
             )
 
+        def _get_slice_index(tag: str) -> int:
+            slice_index = 0
+            for i, ch in enumerate(tag[::-1]):
+                if not ch.isnumeric():
+                    slice_index = -i
+                    break
+            if not slice_index:
+                raise ValueError(
+                    f"The file tag {tag} does not end in numeric characters or is entirely numeric: cannot parse"
+                )
+            return slice_index
+
         def _extract_tilt_series(p: Path) -> str:
-            _split = p.name.split("_")[-1].split(".")
+            tag = p.name.split("_")[0]
+            slice_index = _get_slice_index(tag)
+            return tag[slice_index:]
+
+        def _extract_tilt_tag(p: Path) -> str:
+            tag = p.name.split("_")[0]
+            slice_index = _get_slice_index(tag)
+            return tag[:slice_index]
+
+        def _extract_tilt_angle(p: Path) -> str:
+            _split = p.name.split("_")[2].split(".")
             return ".".join(_split[:-1])
 
         return self._add_tilt(
             file_path,
-            lambda x: x.name.split("_")[1],
             _extract_tilt_series,
+            _extract_tilt_angle,
+            _extract_tilt_tag,
             environment=environment,
         )
 
@@ -514,6 +528,7 @@ class TomographyContext(Context):
             file_path,
             _extract_tilt_series,
             lambda x: ".".join(x.name.split(delimiter)[-1].split(".")[:-1]),
+            lambda x: "",
             environment=environment,
         )
 
@@ -556,7 +571,11 @@ class TomographyContext(Context):
             return OrderedDict({})
         if metadata_file.suffix == ".xml":
             with open(metadata_file, "r") as xml:
-                for_parsing = xml.read()
+                try:
+                    for_parsing = xml.read()
+                except Exception:
+                    logger.warning(f"Failed to parse file {metadata_file}")
+                    return OrderedDict({})
                 data = xmltodict.parse(for_parsing)
             metadata: OrderedDict = OrderedDict({})
             metadata["experiment_type"] = TUIFormValue("tomography")
@@ -574,6 +593,7 @@ class TomographyContext(Context):
                 None, top=True, colour="dark_orange"
             )
             metadata.move_to_end("dose_per_frame", last=False)
+            # logger.info(f"Metadata extracted from {metadata_file}: {metadata}")
             return metadata
         with open(metadata_file, "r") as md:
             mdoc_data = get_global_data(md)
@@ -585,10 +605,11 @@ class TomographyContext(Context):
         mdoc_metadata["image_size_x"] = TUIFormValue(int(mdoc_data["ImageSize"][0]))
         mdoc_metadata["image_size_y"] = TUIFormValue(int(mdoc_data["ImageSize"][1]))
         mdoc_metadata["pixel_size_on_image"] = TUIFormValue(
-            float(mdoc_data["PixelSpacing"])
+            float(mdoc_data["PixelSpacing"]) * 1e-10
         )
         mdoc_metadata["dose_per_frame"] = TUIFormValue(
             None, top=True, colour="dark_orange"
         )
         mdoc_metadata.move_to_end("dose_per_frame", last=False)
+        # logger.info(f"Metadata extracted from {metadata_file}")
         return mdoc_metadata
