@@ -116,7 +116,14 @@ class HoverVisit(Widget):
                 ).json()
                 _default = ""
                 if self.app._default_destination:
-                    if machine_data.get("data_directories"):
+                    if (
+                        self.app._environment.processing_only_mode
+                        and self.app._environment.source
+                    ):
+                        _default = str(self.app._environment.source.resolve()) or str(
+                            Path.cwd()
+                        )
+                    elif machine_data.get("data_directories"):
                         for data_dir in machine_data["data_directories"].keys():
                             if (
                                 self.app._environment.source
@@ -164,13 +171,16 @@ class HoverVisit(Widget):
                         _default = self.app._default_destination + f"/{self._text}"
                 else:
                     _default = "unknown"
-                self.app._queues["input"].put_nowait(
-                    InputResponse(
-                        question="Transfer to: ",
-                        default=_default,
-                        callback=self.app._start_rsyncer,
+                if self.app._environment.processing_only_mode:
+                    self.app._start_rsyncer(_default)
+                else:
+                    self.app._queues["input"].put_nowait(
+                        InputResponse(
+                            question="Transfer to: ",
+                            default=_default,
+                            callback=self.app._start_rsyncer,
+                        )
                     )
-                )
 
 
 class QuickPrompt:
@@ -489,7 +499,7 @@ class MurfeyTUI(App):
         self.rsync_process = rsync_process
         self.analyser = analyser
         self._data_collection_form_complete = False
-        self._info_widget = InfoWidget("Welcome to Murfey :microscope:")
+        self._info_widget = InfoWidget("Welcome to Murfey :microscope: \n")
 
     @property
     def role(self) -> str:
@@ -522,13 +532,16 @@ class MurfeyTUI(App):
                 target=self.rsync_process._process,
             )
 
+        self._info_widget.text += f"{self._source.resolve()} \u2192 {destination} \n"
+
         def rsync_result(update: RSyncerUpdate):
             if not self.rsync_process:
                 raise ValueError("TUI rsync process does not exist")
             if update.outcome is TransferResult.SUCCESS:
-                log.info(
-                    f"File {str(update.file_path)!r} successfully transferred ({update.file_size} bytes)"
-                )
+                # log.info(
+                #     f"File {str(update.file_path)!r} successfully transferred ({update.file_size} bytes)"
+                # )
+                pass
             else:
                 log.warning(f"Failed to transfer file {str(update.file_path)!r}")
                 self.rsync_process.enqueue(update.file_path)
@@ -597,6 +610,7 @@ class MurfeyTUI(App):
         if self._dummy_dc:
             return
         self._environment.data_collection_parameters = json
+        self._info_widget.text += "\n".join(f"{k}: {v}" for k, v in json.items()) + "\n"
         if isinstance(self.analyser._context, TomographyContext):
             self._environment.listeners["data_collection_group_id"] = {
                 self.analyser._context._flush_data_collections
@@ -632,19 +646,6 @@ class MurfeyTUI(App):
 
     async def on_mount(self) -> None:
         self.input_box = InputBox(self, queue=self._queues.get("input"))
-        self._queues["input"].put_nowait(
-            InputResponse(
-                question="Are you using multi-grid?",
-                allowed_responses=["y", "n"],
-                callback=self._set_request_destination,
-            )
-        )
-        # self._queues["input"].put_nowait(
-        #     InputResponse(
-        #         question="Processing parameters: ",
-        #         form={"Voltage [keV]": 300, "Pixel size [U+212b]": 1},
-        #     )
-        # )
         self.log_book = LogBook(self._queues["logs"])
         # self._statusbar = StatusBar()
         self.hovers = (
