@@ -18,7 +18,7 @@ import murfey.server.websocket as ws
 from murfey.server import _transport_object, get_hostname, get_microscope
 from murfey.server import shutdown as _shutdown
 from murfey.server import templates
-from murfey.server.config import from_file
+from murfey.server.config import MachineConfig, from_file
 from murfey.util.models import (
     ContextInfo,
     DCGroupParameters,
@@ -41,7 +41,12 @@ class Settings(BaseSettings):
 
 settings = Settings()
 
-machine_config: dict = {}
+machine_config: MachineConfig = MachineConfig(
+    acquisition_software=[],
+    calibrations={},
+    data_directories={},
+    rsync_basepath=Path("dls/tmp"),
+)
 if settings.murfey_machine_configuration:
     microscope = get_microscope()
     machine_config = from_file(Path(settings.murfey_machine_configuration), microscope)
@@ -187,7 +192,7 @@ async def add_file(file: File):
 async def send_murfey_message(msg: RegistrationMessage):
     if _transport_object:
         _transport_object.transport.send(
-            "murfey_feedback", {"register": msg.registration}
+            machine_config.feedback_queue, {"register": msg.registration}
         )
 
 
@@ -196,29 +201,25 @@ async def request_tomography_preprocessing(visit_name: str, proc_file: ProcessFi
     visit_idx = Path(proc_file.path).parts.index(visit_name)
     core = Path(*Path(proc_file.path).parts[: visit_idx + 1])
     ppath = Path(proc_file.path)
-    sub_dataset = (
-        ppath.relative_to(core).parts[0]
-        if len(ppath.relative_to(core).parts) > 1
-        else ""
-    )
+    sub_dataset = "/".join(ppath.relative_to(core).parts[:-1])
     mrc_out = (
         core
-        / machine_config.get("processed_directory_name", "processed")
+        / machine_config.processed_directory_name
         / sub_dataset
         / "MotionCorr"
         / str(ppath.stem + "_motion_corrected.mrc")
     )
     ctf_out = (
         core
-        / machine_config.get("processed_directory_name", "processed")
+        / machine_config.processed_directory_name
         / sub_dataset
         / "CTF"
         / str(ppath.stem + "_ctf.mrc")
     )
     if not mrc_out.parent.exists():
-        mrc_out.parent.mkdir(parents=True, mode=1411)
+        mrc_out.parent.mkdir(parents=True)
     if not ctf_out.parent.exists():
-        ctf_out.parent.mkdir(parents=True, mode=1411)
+        ctf_out.parent.mkdir(parents=True)
     zocalo_message = {
         "recipes": ["em-tomo-preprocess"],
         "parameters": {
@@ -233,7 +234,7 @@ async def request_tomography_preprocessing(visit_name: str, proc_file: ProcessFi
             "mc_uuid": proc_file.mc_uuid,
         },
     }
-    log.info(f"Sending Zocalo message {zocalo_message}")
+    # log.info(f"Sending Zocalo message {zocalo_message}")
     if _transport_object:
         _transport_object.transport.send("processing_recipe", zocalo_message)
     else:
@@ -241,7 +242,7 @@ async def request_tomography_preprocessing(visit_name: str, proc_file: ProcessFi
             f"Pe-processing was requested for {ppath.name} but no Zocalo transport object was found"
         )
         return proc_file
-    await ws.manager.broadcast(f"Pre-processing requested for {ppath.name}")
+    # await ws.manager.broadcast(f"Pre-processing requested for {ppath.name}")
     return proc_file
 
 
@@ -250,10 +251,10 @@ async def request_tilt_series_alignment(tilt_series: TiltSeries):
     stack_file = (
         Path(tilt_series.motion_corrected_path).parents[1]
         / "align_output"
-        / "aligned_file.mrc"
+        / f"{tilt_series.name}_stack.mrc"
     )
     if not stack_file.parent.exists():
-        stack_file.parent.mkdir(parents=True, mode=1411)
+        stack_file.parent.mkdir(parents=True)
     zocalo_message = {
         "recipes": ["em-tomo-align"],
         "parameters": {
@@ -276,6 +277,7 @@ async def request_tilt_series_alignment(tilt_series: TiltSeries):
     await ws.manager.broadcast(
         f"Processing requested for tilt series {tilt_series.name}"
     )
+
     return tilt_series
 
 
@@ -310,7 +312,7 @@ def shutdown():
 def suggest_path(visit_name, params: SuggestedPathParameters):
     count: int | None = None
     check_path = (
-        machine_config["rsync_basepath"] / params.base_path
+        machine_config.rsync_basepath / params.base_path
         if machine_config
         else Path(f"/dls/{get_microscope()}") / params.base_path
     )
@@ -318,7 +320,7 @@ def suggest_path(visit_name, params: SuggestedPathParameters):
     while check_path.exists():
         count = count + 1 if count else 2
         check_path = check_path.parent / f"{check_path_name}{count}"
-    return {"suggested_path": check_path}
+    return {"suggested_path": check_path.relative_to(machine_config.rsync_basepath)}
 
 
 @router.post("/visits/{visit_name}/register_data_collection_group")
@@ -329,7 +331,7 @@ def register_dc_group(visit_name, dcg_params: DCGroupParameters):
     log.info(f"Registering data collection group on microscope {get_microscope()}")
     dcg_parameters = {
         "session_id": murfey.server.ispyb.get_session_id(
-            microscope="m12",  # get_microscope(),
+            microscope=get_microscope(),
             proposal_code=ispyb_proposal_code,
             proposal_number=ispyb_proposal_number,
             visit_number=ispyb_visit_number,
@@ -337,11 +339,12 @@ def register_dc_group(visit_name, dcg_params: DCGroupParameters):
         ),
         "start_time": str(datetime.datetime.now()),
         "experiment_type": dcg_params.experiment_type,
+        "experiment_type_id": dcg_params.experiment_type_id,
     }
 
     if _transport_object:
         _transport_object.transport.send(
-            "murfey_feedback", {"register": "data_collection_group", **dcg_parameters}  # type: ignore
+            machine_config.feedback_queue, {"register": "data_collection_group", **dcg_parameters}  # type: ignore
         )
     return dcg_parameters
 
@@ -355,7 +358,7 @@ def start_dc(visit_name, dc_params: DCParameters):
     dc_parameters = {
         "visit": visit_name,
         "session_id": murfey.server.ispyb.get_session_id(
-            microscope="m12",  # get_microscope(),
+            microscope=get_microscope(),
             proposal_code=ispyb_proposal_code,
             proposal_number=ispyb_proposal_number,
             visit_number=ispyb_visit_number,
@@ -375,9 +378,12 @@ def start_dc(visit_name, dc_params: DCParameters):
     }
 
     if _transport_object:
-        log.debug(f"Send registration message to murfey_feedback: {dc_parameters}")
+        log.debug(
+            f"Send registration message to {machine_config.feedback_queue}: {dc_parameters}"
+        )
         _transport_object.transport.send(
-            "murfey_feedback", {"register": "data_collection", **dc_parameters}
+            machine_config.feedback_queue,
+            {"register": "data_collection", **dc_parameters},
         )
     return dc_params
 
@@ -391,9 +397,10 @@ def register_proc(visit_name, proc_params: ProcessingJobParameters):
 
     if _transport_object:
         log.info(
-            f"Send processing registration message to murfey_feedback: {proc_parameters}"
+            f"Send processing registration message to {machine_config.feedback_queue}: {proc_parameters}"
         )
         _transport_object.transport.send(
-            "murfey_feedback", {"register": "processing_job", **proc_parameters}
+            machine_config.feedback_queue,
+            {"register": "processing_job", **proc_parameters},
         )
     return proc_params
